@@ -240,7 +240,7 @@ class BonusRecordManager(models.Manager):
     
     @transaction.atomic
     def createBonusRecord(self, user, order, use=0, receive=0, adjust=0, note=None):
-        if not use == 0 and receive == 0:
+        if not use == 0 or not receive == 0:
             record = BonusRecord.objects.create(
                 user=user,
                 order=order,
